@@ -652,7 +652,17 @@ class Application(ConfigurableForServerSidePath, Object):
 			pass
 		except ConnectionAbortedError, err:
 			trans.setError(err)
-		except Exception, err:
+		except (KeyboardInterrupt, SystemExit):
+			raise # do not catch these here
+		except:
+			# For once, we use a bare except here in order to catch
+			# string and non standard exceptions from legacy code
+			# (starting with Python 2.5 you can simply catch Exception;
+			# KeyboardInterrupt, SystemExit will be excluded already
+			# and string exceptions will output deprecation warnings).
+			errClass, err = sys.exc_info()[:2]
+			if not err: # string exception
+				err, errClass = errClass, None
 			urls = {}
 			while 1:
 				trans.setError(err)
@@ -667,7 +677,7 @@ class Application(ConfigurableForServerSidePath, Object):
 					# no custom error page configured
 					break
 				# get custom error page for this exception
-				url = self.errorPage(err.__class__)
+				url = errClass and self.errorPage(errClass)
 				if isHTTPException and not url:
 					# get custom error page for status code
 					code = err.code()
@@ -686,10 +696,16 @@ class Application(ConfigurableForServerSidePath, Object):
 					pass
 				except ConnectionAbortedError, err:
 					trans.setError(err)
-				except Exception, err:
+				except (KeyboardInterrupt, SystemExit):
+					raise # do not catch these here
+				except:
+					# Once more, catch all other kinds of exceptions here.
 					# If the custom error page itself throws an exception,
 					# display the new exception instead of the original one,
 					# so we notice that something is broken here.
+					errClass, err = sys.exc_info()[:2]
+					if not err: # string exception
+						err, errClass = errClass, None
 					url = None
 				if url:
 					return # error has already been handled
